aboutsummaryrefslogtreecommitdiff
path: root/app/Controllers
diff options
context:
space:
mode:
authorGravatar Marien Fressinaud <dev@marienfressinaud.fr> 2014-10-26 12:22:13 +0100
committerGravatar Marien Fressinaud <dev@marienfressinaud.fr> 2014-10-26 12:22:13 +0100
commit5d6407a0bf0ecee7017f9d6c6c110b7afa98fff0 (patch)
tree493652d2de8db143e111e1c7b1c7627c2e68fa55 /app/Controllers
parent20b40aa85ea23e00e71e9d7ab8f3b08b51f16f41 (diff)
Update i18n
- Fix i18n strings - Fix typo profil -> profile See https://github.com/marienfressinaud/FreshRSS/issues/678
Diffstat (limited to 'app/Controllers')
-rw-r--r--app/Controllers/authController.php6
-rw-r--r--app/Controllers/userController.php16
2 files changed, 11 insertions, 11 deletions
diff --git a/app/Controllers/authController.php b/app/Controllers/authController.php
index 4af39cb71..a08f906e3 100644
--- a/app/Controllers/authController.php
+++ b/app/Controllers/authController.php
@@ -143,7 +143,7 @@ class FreshRSS_auth_Controller extends Minz_ActionController {
}
// All is good, go back to the index.
- Minz_Request::good(_t('login'),
+ Minz_Request::good(_t('feedback.login.success'),
array('c' => 'index', 'a' => 'index'));
} else {
Minz_Log::warning('Password mismatch for' .
@@ -182,7 +182,7 @@ class FreshRSS_auth_Controller extends Minz_ActionController {
Minz_Session::_param('passwordHash', $s);
FreshRSS_Auth::giveAccess();
- Minz_Request::good(_t('login'),
+ Minz_Request::good(_t('feedback.login.success'),
array('c' => 'index', 'a' => 'index'));
} else {
Minz_Log::warning('Unsafe password mismatch for user ' . $username);
@@ -274,7 +274,7 @@ class FreshRSS_auth_Controller extends Minz_ActionController {
public function logoutAction() {
invalidateHttpCache();
FreshRSS_Auth::removeAccess();
- Minz_Request::good(_t('disconnected'),
+ Minz_Request::good(_t('feedback.logout.success'),
array('c' => 'index', 'a' => 'index'));
}
diff --git a/app/Controllers/userController.php b/app/Controllers/userController.php
index 61d33437d..2343520ca 100644
--- a/app/Controllers/userController.php
+++ b/app/Controllers/userController.php
@@ -23,10 +23,10 @@ class FreshRSS_user_Controller extends Minz_ActionController {
}
/**
* This action displays the user profil page.
*/
- public function profilAction() {
- Minz_View::prependTitle(_t('users.profil') . ' · ');
+ public function profileAction() {
+ Minz_View::prependTitle(_t('gen.title.user_profile') . ' · ');
if (Minz_Request::isPost()) {
$ok = true;
@@ -74,11 +74,11 @@ class FreshRSS_user_Controller extends Minz_ActionController {
}
if ($ok) {
- Minz_Request::good('users.profil.updated',
- array('c' => 'user', 'a' => 'profil'));
+ Minz_Request::good(_t('feedback.user_profile.updated'),
+ array('c' => 'user', 'a' => 'profile'));
} else {
- Minz_Request::bad('error_occurred',
- array('c' => 'user', 'a' => 'profil'));
+ Minz_Request::bad(_t('error_occurred'),
+ array('c' => 'user', 'a' => 'profile'));
}
}
}
@@ -92,7 +92,7 @@ class FreshRSS_user_Controller extends Minz_ActionController {
array('error' => array(_t('access_denied'))));
}
- Minz_View::prependTitle(_t('users.manage') . ' · ');
+ Minz_View::prependTitle(_t('gen.title.user_management') . ' · ');
// Get the correct current user.
$userDAO = new FreshRSS_UserDAO();
@@ -23,10 +23,10 @@ class FreshRSS_user_Controller extends Minz_ActionController {
}
/**
- * This action displays the user profil page.
+ * This action displays the user profile page.
*/